@@ -1,17 +1,54 @@
+from __future__ import annotations
+
 from math import pi
+from typing import List, Optional, Tuple, Union
+
+from brian2.units import Quantity
 
 
 class EphysProperties(object):
     """
-    WARNING: This class is under development. Some of its features might change
-    or become part of the Compartment & NeuronModel classes.
+    A class for calculating various important electrophysiological properties
+    for a single compartment.
 
-    A class that helps to declare all necessary model parameters.
+    Note
+    ----
+    An EphysProperties object is automatically created and linked to a 
+    :class:`.Compartment`, :class:`.Soma`, or :class:`.Dendrite` object
+    during the instantiation of the latter.
+
+    Parameters
+    ----------
+
+    name : str, optional
+        A compartment's name, by default ``None``
+    length : ~brian2.units.fundamentalunits.Quantity, optional
+        A compartment's length, by default ``None``
+    diameter : ~brian2.units.fundamentalunits.Quantity, optional
+        A compartment's diameter, by default ``None``
+    cm : ~brian2.units.fundamentalunits.Quantity, optional
+        Specific capacitance (usually μF / cm^2), by default ``None``
+    gl : ~brian2.units.fundamentalunits.Quantity, optional
+        Specific leakage conductance (usually μS / cm^2), by default ``None``
+    r_axial : ~brian2.units.fundamentalunits.Quantity, optional
+        Axial resistance (usually Ohm * cm), by default ``None``
+    v_rest : ~brian2.units.fundamentalunits.Quantity, optional
+        Resting membrane voltage, by default ``None``
+    scale_factor : float, optional
+        A global area scale factor, by default ``1.0``
+    spine_factor : float, optional
+        A dendritic area scale factor to account for spines, by default ``1.0``
     """
 
-    def __init__(self, name=None, length=None, diameter=None, cm=None,
-                 gl=None, r_axial=None, v_rest=None, scale_factor=1.0,
-                 spine_factor=1.0):
+    def __init__(self, name: Optional[str] = None,
+                 length: Optional[Quantity] = None,
+                 diameter: Optional[Quantity] = None,
+                 cm: Optional[Quantity] = None,
+                 gl: Optional[Quantity] = None,
+                 r_axial: Optional[Quantity] = None,
+                 v_rest: Optional[Quantity] = None,
+                 scale_factor: float = 1.0,
+                 spine_factor: float = 1.0):
         self.name = name
         self.length = length
         self.diameter = diameter
@@ -23,9 +60,6 @@ class EphysProperties(object):
         self.spine_factor = spine_factor
 
     def __str__(self):
-        """
-        Print useful information about an EphysProperties object.
-        Usage -> print(object_name)"""
         attrs = self.__dict__
         details = [f"\u2192 {i}: \n{attrs[i]}\n" for i in attrs]
         msg = ("OBJECT:\n{0}\n"
@@ -34,19 +68,26 @@ class EphysProperties(object):
         return msg.format(self.__class__, "\n".join(details))
 
     @property
-    def total_area_factor(self):
-        return self.scale_factor * self.spine_factor
-
-    @property
-    def area(self):
+    def total_area_factor(self) -> float:
         """
-        Returns the surface area a of a compartment (open cylinder) based
-        on its length and diameter.
+        The total surface are factor.
 
         Returns
         -------
-        TYPE
-            Description
+        float
+        """
+        return self.scale_factor * self.spine_factor
+
+    @property
+    def area(self) -> Quantity:
+        """
+        A compartment's surface area (open cylinder) based on its length and
+        diameter.
+
+        Returns
+        -------
+        ~brian2.units.fundamentalunits.Quantity
+            A compartment's surface area
         """
         try:
             return pi * self.length * self.diameter * self.total_area_factor
@@ -56,10 +97,14 @@ class EphysProperties(object):
                    "returned None instead\n"))
 
     @property
-    def capacitance(self):
+    def capacitance(self) -> Quantity:
         """
-        Returns the absolute membrane capacitance of a single compartment
-        based on its surface area and its specific membrane capacitance.
+        A compartment's absolute capacitance based on its specific capacitance
+        (cm) and surface area.
+
+        Returns
+        -------
+        :class:`~brian2.units.fundamentalunits.Quantity`
         """
         try:
             return self.area * self.cm
@@ -69,10 +114,14 @@ class EphysProperties(object):
                    "returned None instead"))
 
     @property
-    def g_leakage(self):
+    def g_leakage(self) -> Quantity:
         """
-        Returns the absolute leakage conductance of a single compartment based
-        on its surface area and its specific leakage conductance.
+        A compartment's absolute leakage conductance based on its specific
+        leakage conductance (gl) and surface area.
+
+        Returns
+        -------
+        :class:`~brian2.units.fundamentalunits.Quantity`
         """
         try:
             return self.area * self.gl
@@ -82,13 +131,13 @@ class EphysProperties(object):
                    "returned None instead"))
 
     @property
-    def parameters(self):
-        """parameters _summary_
+    def parameters(self) -> dict:
+        """
+        Returns a dictionary of all electrophysiological parameters.
 
         Returns
         -------
-        _type_
-            _description_
+        dict
         """
         d = {}
         error = None
@@ -117,12 +166,16 @@ class EphysProperties(object):
         return d
 
     @property
-    def g_cylinder(self):
+    def g_cylinder(self) -> Quantity:
         """
-        The conductance (of coupling currents) passing through a cylindri_cal
+        The conductance (of coupling currents) passing through a cylindrical
         compartment based on its dimensions and its axial resistance. To be
         used when then the total number of compartments is low and the
         adjacent-to-soma compartments are highly coupled with the soma.
+
+        Returns
+        -------
+        :class:`~brian2.units.fundamentalunits.Quantity`
         """
         try:
             ri = (4*self.r_axial*self.length) / (pi*self.diameter**2)
@@ -134,7 +187,7 @@ class EphysProperties(object):
             return 1/ri
 
     @staticmethod
-    def g_couple(comp1, comp2):
+    def g_couple(comp1: EphysProperties, comp2: EphysProperties) -> Quantity:
         """
         The conductance (of coupling currents) between the centers of
         two adjacent cylindrical compartments, based on their dimensions
@@ -142,15 +195,14 @@ class EphysProperties(object):
 
         Parameters
         ----------
-        comp1 : TYPE
-            Description
-        comp2 : TYPE
-            Description
+        comp1 : EphysProperties
+            An EphysProperties object
+        comp2 : EphysProperties
+            An EphysProperties object
 
         Returns
         -------
-        TYPE
-            Description
+        :class:`~brian2.units.fundamentalunits.Quantity`
         """
         try:
             r1 = (4 * comp1.r_axial * comp1.length) / (pi * comp1.diameter**2)
